Great Music Products Product Details

|  |  |  |  | VIEWCART SEARCH CONTACT POLICIES HOME SETUP HELP INTERNATIONAL ACCOUNT LOGIN ACCOUNT HISTORY ORDER STATUS SITEMAP | OR TRY ADVANCED SEARCH

Accordions |
Amplifiers |
Bagpipes |
Banjos |
Basses |
Belly Dancing |
Books/DVD/CD's |
Brass Instruments |
Guitars & Acc. |
Harmonicas |
Keyboards/Pianos |
Lighting/DJ |
Mandolins |
Melodicas |
Microphones & Accs. |
Pro Audio |
Percussion |
Rack Cases |
Software |
Stage Snakes |
String Instruments |
Ukuleles |
Unique String Inst. |
Unique Wind Items |
Woodwind Inst. |
Setup Help |
Warranty/Returns |
Affiliates Login |
International Help |
| We're really sorry... ...we don't currently have that one in stock Please add your email and we'll notify you when it's back Mid-East Velvet Drawstring Bag for Finger Cymbals 4"x5.5" - Black (Back to product)
Home » Belly Dancing Products » Finger Cymbals |
Product ID: VBAG Mid-East Velvet Drawstring Bag for Finger Cymbals 4"x5.5" - Black Discounts Apply ! Free Shipping On Most Items Over $150, Lower 48 States USA!!
This black velvet bag is perfect to store and carry zills, reeds, picks and more. 4 inch wide opening and 5.5 inches deep with draw strings. Made in China

Email Friend

Ask A Question
List Price: $1.38
SALE PRICE: $1.38

« Previous | Next »

home | products | about us | search | checkout

contact us | policies | international | search

Copyright 2015 GREAT MUSIC PRODUCTS LLC All Rights Reserved Every effort has been made to ensure the accuracy of information presented as factual; however errors may exist. All information published online by Great Music Products LLC is subject to change without notice. International Customers Are Responsible For Duties And Taxes Due.